TextEdit

Struct TextEdit 

pub struct TextEdit {
    pub text: String,
    pub range: TextRange,
    pub snippet: Option<String>,
}
A text edit (with an optional snippet - i.e tab stops and/or placeholders).

Fields

text: String

Replacement text for the text edit.

range: TextRange

Range to which the text edit will be applied.

snippet: Option<String>

Formatted snippet for the text edit (includes tab stops and/or placeholders).

Implementations

Source

impl TextEdit

pub fn new(text: String, range: TextRange, snippet: Option<String>) -> Self

Creates text edit.

pub fn insert(text: String, offset: TextSize) -> Self

Creates text edit for inserting at the given offset.

pub fn insert_with_snippet( text: String, offset: TextSize, snippet: Option<String>, ) -> Self

Creates text edit for inserting at the given offset (including an optional snippet).

pub fn replace(text: String, range: TextRange) -> Self

Creates text edit for replacing the given range.

pub fn replace_with_snippet( text: String, range: TextRange, snippet: Option<String>, ) -> Self

Creates text edit for replacing the given range (including an optional snippet) - i.e an alias of Self::new.

pub fn delete(range: TextRange) -> Self

Creates a text edit for deleting the specified range.